@@ -55,9 +55,12 @@ def build_grai_metadata_from_node(
 def build_grai_metadata_from_edge(
     current: Edge, version: Literal["v1"] = "v1"
 ) -> base_schemas.GraiEdgeMetadata:
-    return base_schemas.GraiEdgeMetadata({"version": "v1"})
-    # data = {"version": version}
-    # return base_schemas.GraiEdgeMetadata(**data)
+    data = {"version": version}
+
+    data["edge_type"] = "Edge"
+    data["Edge_attributes"] = None
+    
+    return base_schemas.EdgeV1(**data)
 
 
 @multimethod
